#!/bin/bash
#
# Purpose: This script tests conversion of AWS l1b netcdf files to l1b
# and l1c BUFR files
#
# Instructions:
# - Before running script, you need to export AAPP_AWS_HOME, where
#   this is the full path of the directory where the executables have been
#   installed (the bin directory).
# - Then: ./run_aws.sh
#
# See the AAPP-AWS User Manual at https://nwp-saf.eumetsat.int/site/software/aapp/documentation/
# for more detail on AAPP-AWS functionality.

#### CONSTANTS

THIS_DIR=$(cd $(dirname ${BASH_SOURCE[0]}); echo ${PWD})
INPUTS_DIR=${THIS_DIR}/inputs
OUTPUTS_DIR=${THIS_DIR}/outputs
LOGS_DIR=${THIS_DIR}/logs

AAPP_AWS_HOME=${AAPP_AWS_HOME:?"ERROR: Please export AAPP_AWS_HOME (the 'bin' directory) before running this script."}
ENVIRONMENT_FILE=${AAPP_AWS_HOME}/aapp_aws_env.sh

# AWS Processing options
REF_BAND=3    #user can change this if desired
BUFR_NL=${INPUTS_DIR}/aws_bufr.nl
AVERAGING_NL=${INPUTS_DIR}/aws_average.nl


#### MAIN

if [[ ! -f ${ENVIRONMENT_FILE} ]]; then
    echo "ERROR: environment file aapp_aws_env.sh not found in \${AAPP_AWS_HOME}."
    exit 1
fi

source ${ENVIRONMENT_FILE}
set -u

# Set reference band options for conversion to l1c
# Data will be re-mapped to the geolocations of the reference band
echo "Remapping in conversion to l1c will use reference band ${REF_BAND}"
band_str="band${REF_BAND}"
band_option="-b ${REF_BAND}"
if [[ "${REF_BAND}" == "1" ]]; then
  band_option=""
fi

# Test conversion of AWS l1b netcdf files to l1b and l1c BUFR files

mkdir -p ${OUTPUTS_DIR} ${LOGS_DIR}

infiles=$(ls ${INPUTS_DIR}/W*.nc)

for infile in ${infiles}; do
    infile_name=$(basename $infile)

    echo -e "\nProcessing: ${infile_name}"
    set $(IFS=_; echo ${infile_name})
    outfile_root=AWS_${8}_${9}

    echo "Convert netcdf to l1b BUFR"
    outfile_l1b=${OUTPUTS_DIR}/${outfile_root}_nc-to-bufr_l1b.bufr
    aws_netcdf_to_bufr_1b.exe -i ${infile} -o ${outfile_l1b} &> ${LOGS_DIR}/aws_netcdf_to_bufr_1b.out
    if [[ $? -ne 0 ]]; then
      echo "ERROR: aws_netcdf_to_bufr_1b.exe failed"
      exit 1
    fi

    echo "Convert netcdf to l1c BUFR (with spatial averaging and thinning specified in namelist files)"
    outfile_l1c=${OUTPUTS_DIR}/${outfile_root}_nc-to-bufr_l1c.${band_str}.bufr_nl.bufr
    aws_netcdf_to_bufr_1c.exe ${band_option} -i ${infile} -o ${outfile_l1c} -n ${BUFR_NL} -a ${AVERAGING_NL} &> ${LOGS_DIR}/aws_netcdf_to_bufr_1c.${band_str}.bufr_nl.out
    if [[ $? -ne 0 ]]; then
      echo "ERROR: aws_netcdf_to_bufr_1c.exe (reference band ${REF_BAND} with averaging and thinning) failed"
      exit 1
    fi
done

echo "Test complete"
